@@ -22,20 +22,30 @@ mod store;
 const SIZE_LIMIT: u64 = 1024;
 
 /// how often should we prune the expired entries?
-const PRUNE_EXPIRED_FREQ_S: u64 = 5;
+pub const PRUNE_EXPIRED_FREQ: std::time::Duration = std::time::Duration::from_secs(5);
 
 pub type BootstrapDriver = futures::future::BoxFuture<'static, ()>;
 
+/// Run a bootstrap with the default prune frequency [`PRUNE_EXPIRED_FREQ`].
 pub async fn run(
     addr: impl Into<SocketAddr> + 'static,
     proxy_list: Vec<String>,
+) -> Result<(BootstrapDriver, SocketAddr), String> {
+    run_with_prune_freq(addr, proxy_list, PRUNE_EXPIRED_FREQ).await
+}
+
+/// Run a bootstrap server with a set prune frequency.
+pub async fn run_with_prune_freq(
+    addr: impl Into<SocketAddr> + 'static,
+    proxy_list: Vec<String>,
+    prune_frequency: std::time::Duration,
 ) -> Result<(BootstrapDriver, SocketAddr), String> {
     let store = Store::new(proxy_list);
     {
         let store = store.clone();
         tokio::task::spawn(async move {
             loop {
-                tokio::time::sleep(std::time::Duration::from_secs(PRUNE_EXPIRED_FREQ_S)).await;
+                tokio::time::sleep(prune_frequency).await;
                 store.prune();
             }
         });
